# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteBureaus(BaseModel):
    delete_bureaus: Optional[list[Optional["DeleteBureausDeleteBureaus"]]] = Field(
        alias="deleteBureaus"
    )


class DeleteBureausDeleteBureaus(BaseModel):
    id: str
    state: EntityState


DeleteBureaus.model_rebuild()
