# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryInvestmentFundsExpanded(BaseModel):
    investment_funds: Optional["QueryInvestmentFundsExpandedInvestmentFunds"] = Field(
        alias="investmentFunds"
    )


class QueryInvestmentFundsExpandedInvestmentFunds(BaseModel):
    results: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResults"]]
    ]


class QueryInvestmentFundsExpandedInvestmentFundsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryInvestmentFundsExpandedInvestmentFundsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsFeeds"]]
    ]
    links: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsLinks"]]
    ]
    workflow: Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsWorkflow"]
    location: Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsLocation"]
    h_3: Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsH3"] = Field(
        alias="h3"
    )
    amount: Optional[Any]
    amount_currency: Optional[str] = Field(alias="amountCurrency")
    fund_type: Optional[str] = Field(alias="fundType")
    vintage: Optional[int]
    target_size: Optional[Any] = Field(alias="targetSize")
    target_size_currency: Optional[str] = Field(alias="targetSizeCurrency")
    organizations: Optional[
        list[
            Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsOrganizations"]
        ]
    ]
    investments: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsInvestments"]]
    ]
    parent_fund: Optional[
        "QueryInvestmentFundsExpandedInvestmentFundsResultsParentFund"
    ] = Field(alias="parentFund")
    child_funds: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsChildFunds"]]
    ] = Field(alias="childFunds")


class QueryInvestmentFundsExpandedInvestmentFundsResultsOwner(BaseModel):
    id: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryInvestmentFundsExpandedInvestmentFundsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryInvestmentFundsExpandedInvestmentFundsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryInvestmentFundsExpandedInvestmentFundsResultsOrganizations(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsInvestments(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsParentFund(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsChildFunds(BaseModel):
    id: str
    name: str


QueryInvestmentFundsExpanded.model_rebuild()
QueryInvestmentFundsExpandedInvestmentFunds.model_rebuild()
QueryInvestmentFundsExpandedInvestmentFundsResults.model_rebuild()
