# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdateBureau(BaseModel):
    update_bureau: Optional["UpdateBureauUpdateBureau"] = Field(alias="updateBureau")


class UpdateBureauUpdateBureau(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]


UpdateBureau.model_rebuild()
