# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RemoveAgentsFromDesk(BaseModel):
    remove_agents_from_desk: Optional["RemoveAgentsFromDeskRemoveAgentsFromDesk"] = (
        Field(alias="removeAgentsFromDesk")
    )


class RemoveAgentsFromDeskRemoveAgentsFromDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["RemoveAgentsFromDeskRemoveAgentsFromDeskBureau"]
    agents: Optional[list[Optional["RemoveAgentsFromDeskRemoveAgentsFromDeskAgents"]]]
    agent_count: Optional[int] = Field(alias="agentCount")


class RemoveAgentsFromDeskRemoveAgentsFromDeskBureau(BaseModel):
    id: str


class RemoveAgentsFromDeskRemoveAgentsFromDeskAgents(BaseModel):
    id: str
    name: str


RemoveAgentsFromDesk.model_rebuild()
RemoveAgentsFromDeskRemoveAgentsFromDesk.model_rebuild()
