# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountBureaus(BaseModel):
    count_bureaus: Optional["CountBureausCountBureaus"] = Field(alias="countBureaus")


class CountBureausCountBureaus(BaseModel):
    count: Optional[Any]


CountBureaus.model_rebuild()
