# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class QueryBureaus(BaseModel):
    bureaus: Optional["QueryBureausBureaus"]


class QueryBureausBureaus(BaseModel):
    results: Optional[list["QueryBureausBureausResults"]]


class QueryBureausBureausResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryBureausBureausResultsOwner"
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desk_count: Optional[int] = Field(alias="deskCount")


class QueryBureausBureausResultsOwner(BaseModel):
    id: str


QueryBureaus.model_rebuild()
QueryBureausBureaus.model_rebuild()
QueryBureausBureausResults.model_rebuild()
