# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountDesks(BaseModel):
    count_desks: Optional["CountDesksCountDesks"] = Field(alias="countDesks")


class CountDesksCountDesks(BaseModel):
    count: Optional[Any]


CountDesks.model_rebuild()
