# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteBureau(BaseModel):
    delete_bureau: Optional["DeleteBureauDeleteBureau"] = Field(alias="deleteBureau")


class DeleteBureauDeleteBureau(BaseModel):
    id: str
    state: EntityState


DeleteBureau.model_rebuild()
