# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class GetBureau(BaseModel):
    bureau: Optional["GetBureauBureau"]


class GetBureauBureau(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetBureauBureauOwner"
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desks: Optional[list[Optional["GetBureauBureauDesks"]]]
    desk_count: Optional[int] = Field(alias="deskCount")


class GetBureauBureauOwner(BaseModel):
    id: str


class GetBureauBureauDesks(BaseModel):
    id: str
    name: str


GetBureau.model_rebuild()
GetBureauBureau.model_rebuild()
