# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllDesks(BaseModel):
    delete_all_desks: Optional[list[Optional["DeleteAllDesksDeleteAllDesks"]]] = Field(
        alias="deleteAllDesks"
    )


class DeleteAllDesksDeleteAllDesks(BaseModel):
    id: str
    state: EntityState


DeleteAllDesks.model_rebuild()
