# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class CreateDesk(BaseModel):
    create_desk: Optional["CreateDeskCreateDesk"] = Field(alias="createDesk")


class CreateDeskCreateDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["CreateDeskCreateDeskBureau"]


class CreateDeskCreateDeskBureau(BaseModel):
    id: str


CreateDesk.model_rebuild()
CreateDeskCreateDesk.model_rebuild()
