# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class GetDesk(BaseModel):
    desk: Optional["GetDeskDesk"]


class GetDeskDesk(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetDeskDeskOwner"
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["GetDeskDeskBureau"]
    agents: Optional[list[Optional["GetDeskDeskAgents"]]]
    agent_count: Optional[int] = Field(alias="agentCount")


class GetDeskDeskOwner(BaseModel):
    id: str


class GetDeskDeskBureau(BaseModel):
    id: str


class GetDeskDeskAgents(BaseModel):
    id: str


GetDesk.model_rebuild()
GetDeskDesk.model_rebuild()
