# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdateDesk(BaseModel):
    update_desk: Optional["UpdateDeskUpdateDesk"] = Field(alias="updateDesk")


class UpdateDeskUpdateDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["UpdateDeskUpdateDeskBureau"]


class UpdateDeskUpdateDeskBureau(BaseModel):
    id: str


UpdateDesk.model_rebuild()
UpdateDeskUpdateDesk.model_rebuild()
