# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllBureaus(BaseModel):
    delete_all_bureaus: Optional[list[Optional["DeleteAllBureausDeleteAllBureaus"]]] = (
        Field(alias="deleteAllBureaus")
    )


class DeleteAllBureausDeleteAllBureaus(BaseModel):
    id: str
    state: EntityState


DeleteAllBureaus.model_rebuild()
